/**
 * Written by Fyodor Menshikov 11.04.2015
 */

import java.io.*;
import java.util.*;

class Main {

	static class Assert {
		static void check(boolean e) {
			if (!e) {
				throw new Error();
			}
		}
	}

	static class Result {

		static class Builder {

			Integer period = null;

			Integer preperiod = null;

			Builder period(int period) {
				this.period = period;
				return this;
			}

			Builder preperiod(int preperiod) {
				this.preperiod = preperiod;
				return this;
			}

			Result build() {
				return new Result(period, preperiod);
			}
		}

		final int period;

		final int preperiod;

		Result(int period, int preperiod) {
			this.period = period;
			this.preperiod = preperiod;
		}

		@Override
		public String toString() {
			return period + " " + preperiod;
		}
	}

	Scanner in;

	PrintWriter out;

	static final int REM_COUNT = 32; // 30 is enough

	void printArray(String title, int a[]) {
		out.print(title + ":");
		for (int i = 0; i < a.length; i++) {
			out.print(" " + a[i]);
		}
		out.println();
	}

	int gcd(int a, int b) {
		while (b != 0) {
			int t = a % b;
			a = b;
			b = t;
		}
		return a;
	}

	int getDivisorCount(int n, int d) {
		int count = 0;
		while (n % d == 0) {
			n /= d;
			count++;
		}
		return count;
	}

	List<Integer> getPrimeDivisors(int n) {
		Assert.check(n > 1);
		final List<Integer> primeDivisors = new ArrayList<>();
		int d = 2;
		while (d * d <= n) {
			if (n % d == 0) {
				primeDivisors.add(d);
				n /= d;
			} else {
				d++;
			}
		}
		primeDivisors.add(n);
		return primeDivisors;
	}

	Map<Integer, Integer> getDivisorMap(final int n) {
		final Map<Integer, Integer> divisorToCount = new HashMap<>();
		for (int divisor : getPrimeDivisors(n)) {
			final Integer prevCount = divisorToCount.get(divisor);
			final int count;
			if (prevCount == null) {
				count = 1;
			} else {
				count = prevCount + 1;
			}
			divisorToCount.put(divisor, count);
		}
		return divisorToCount;
	}

	int pow(int n, int pow) {
		int p = 1;
		for (int i = 0; i < pow; i++) {
			p *= n;
		}
		return p;
	}

	int fi(final int n) {
		final Map<Integer, Integer> divisorMap = getDivisorMap(n);
		int product = 1;
		for (final int divisor : divisorMap.keySet()) {
			final int power = divisorMap.get(divisor);
			product *= pow(divisor, power - 1) * (divisor - 1);
		}
		return product;
	}

	long powMod(int base, int power, int mod) {
		if (power == 0) {
			return 1 % mod;
		} else if (power % 2 == 0) {
			long pm = powMod(base, power / 2, mod);
			return (pm * pm) % mod;
		} else {
			return (powMod(base, power - 1, mod) * base) % mod;
		}
	}

	List<Integer> getDivisors(int n) {
		final List<Integer> divisors = new ArrayList<>();
		int d = 1;
		while (d * d < n) {
			if (n % d == 0) {
				divisors.add(d);
				divisors.add(n / d);
			}
			d++;
		}
		if (d * d == n) {
			divisors.add(d);
		}
		return divisors;
	}

	List<Integer> sort(List<Integer> original) {
		List<Integer> sorted = new ArrayList<>(original);
		Collections.sort(sorted);
		return sorted;
	}

	Result solve(int num, int den) {
		int gcd = gcd(num, den);
		num /= gcd;
		den /= gcd;
		int preperiod = Math.max(getDivisorCount(den, 2), getDivisorCount(den, 5));
		for (int i = 0; i < preperiod; i++) {
			long tmp = num * 10L;
			int digit = (int)(tmp / den);
			num = (int)(tmp % den);
		}
		for (int period : sort(getDivisors(fi(den)))) {
			if (num * powMod(10, period, den) % den == num) {
				return new Result.Builder().period(period).preperiod(preperiod).build();
			}
		}
		throw new Error();
	}

	void solve() {
		int num = in.nextInt();
		int den = in.nextInt();
		out.println(solve(num, den));
	}

	void run() {
		try {
			in = new Scanner(new FileReader("fraction.in"));
			out = new PrintWriter(new FileWriter("fraction.out"));
		} catch (IOException e) {
			throw new Error(e);
		}
		try {
			solve();
		} finally {
			out.close();
		}
	}

	public static void main(String args[]) {
		new Main().run();
	}
}
