/**
 * Written by Fyodor Menshikov 11.04.2015
 */

import java.io.*;
import java.util.*;

class Main {

	static class Assert {
		static void check(boolean e) {
			if (!e) {
				throw new Error();
			}
		}
	}

	static class Result {

		static class Builder {

			Integer period = null;

			Integer preperiod = null;

			Builder period(int period) {
				this.period = period;
				return this;
			}

			Builder preperiod(int preperiod) {
				this.preperiod = preperiod;
				return this;
			}

			Result build() {
				return new Result(period, preperiod);
			}
		}

		final int period;

		final int preperiod;

		Result(int period, int preperiod) {
			this.period = period;
			this.preperiod = preperiod;
		}

		@Override
		public String toString() {
			return period + " " + preperiod;
		}
	}

	Scanner in;

	PrintWriter out;

	static final int REM_COUNT = 32; // 30 is enough

	void printArray(String title, int a[]) {
		out.print(title + ":");
		for (int i = 0; i < a.length; i++) {
			out.print(" " + a[i]);
		}
		out.println();
	}

	Result solve(int num, int den) {
		Assert.check(0 <= num && num < den);
		int startRems[] = new int[REM_COUNT];
		for (int i = 0; i < REM_COUNT; i++) {
			startRems[i] = num;
			long tmp = num * 10L;
			int digit = (int)(tmp / den);
			num = (int)(tmp % den);
			Assert.check(0 <= digit && digit <= 9);
			Assert.check(0 <= num && num < den);
		}
		// printArray("startRems", startRems);
		int lastRems[] = startRems.clone();
		int i = REM_COUNT;
		while (true) {
			lastRems[i % REM_COUNT] = num;
			if (num == startRems[REM_COUNT - 1]) {
				break;
			}
			long tmp = num * 10L;
			int digit = (int)(tmp / den);
			num = (int)(tmp % den);
			Assert.check(0 <= digit && digit <= 9);
			Assert.check(0 <= num && num < den);
			i++;
		}
		// printArray("lastRems", lastRems);
		int period = i - (REM_COUNT - 1);
		while (i - period >= 0 && startRems[i - period] == lastRems[i % REM_COUNT]) {
			// out.print("i - period = " + (i - period));
			// out.println(" i % REM_COUNT = " + (i % REM_COUNT));
			i--;
		}
		int preperiod = i - period + 1;
		return new Result.Builder().period(period).preperiod(preperiod).build();
	}

	void solve() {
		int num = in.nextInt();
		int den = in.nextInt();
		out.println(solve(num, den));
	}

	void run() {
		try {
			in = new Scanner(new FileReader("fraction.in"));
			out = new PrintWriter(new FileWriter("fraction.out"));
		} catch (IOException e) {
			throw new Error(e);
		}
		try {
			solve();
		} finally {
			out.close();
		}
	}

	public static void main(String args[]) {
		new Main().run();
	}
}
