#include <cstdio>
#include <algorithm>
#include <vector>
#include <climits>

const int INF = LONG_MAX;

struct PrimeFactor{

  int factor;

  int count;

  PrimeFactor(int factor, int count)
    : factor(factor)
    , count(count)
  {}

};

//     
std::vector<PrimeFactor> factorize(int x) {
  std::vector<PrimeFactor> p;
  for (int i = 2; i * i <= x; i++) {
    if (x % i == 0) {
      int count = 0;
      while (x % i == 0) {
        x /= i;
        ++count;
      }
      p.push_back(PrimeFactor(i, count));
    }
  }
  if (x > 1) {
    p.push_back(PrimeFactor(x, 1));
  }
  return p;
}

//  
int fi(int x) {
   int result = 1;
   for (int i = 2; i * i <= x; i++) {
     int ipow = 1;
     while (x % i == 0) {
       x /= i;
       ipow *= i;
     }
     result *= ipow - ipow / i;
   }
   if (x > 1) {
     result *= x - 1;
   }
   return result;
}

//   a   b   m
int intpow(int a, int b, int m) {
  if (b == 1) {
    return a % m;
  }
  int half_pow = intpow(a, b / 2, m);
  int result = (long long) half_pow * half_pow % m;
  if (b % 2 == 1) {
    result = (long long) result * a % m;
  }
  return result;
}

// ,   len   (  )
bool isPeriodLength(int len, int b) {
  int p = intpow(10, len, b);
  return p == 1;
}

int gcd(int a, int b) {
  while (b != 0) {
    int c = a % b;
    a = b;
    b = c;
  }
  return a;
}

//         b,    2  5
int periodLength(const std::vector<PrimeFactor> &p, int b, int k = 0, int curProduct = 1) {
  if (k == p.size()) {
    if (isPeriodLength(curProduct, b)) {
      return curProduct;
    } else {
      return INF;
    }
  }
  int result = periodLength(p, b, k + 1, curProduct); // p[i].factor in zero power
  for (int i = 0; i < p[k].count; i++) {
    curProduct *= p[k].factor;
    int new_len = periodLength(p, b, k + 1, curProduct);
    if (new_len < result) {
      result = new_len;
    }
  }
  return result;
}

int main() {
   freopen("fraction.in", "r", stdin);
   freopen("fraction.out", "w", stdout);  
   int a, b;
   scanf("%d %d", &a, &b);
   int nod = gcd(a, b);
   a /= nod;
   b /= nod;

   int n2 = 0;
   while ((b & 1) == 0) {
     n2++;
     b >>= 1;
   }

   int n5 = 0;
   while (b % 5 == 0) {
     n5++;
     b /= 5;
   }

   int preperiod = std::max(n2, n5);   

   int period;
   if (b == 1) {
     period = 1;
   } else {
     int f = fi(b); // Euler function
     std::vector<PrimeFactor> p = factorize(f);
     period = periodLength(p, b);
   }

   printf("%d %d\n", period, preperiod);

   return 0;
}

