// another checker without floating-point arithmetics

#include "testlib.h"
#include <vector>

using namespace std;

struct Point {
  int x, y;
};

inline long long area(Point a, Point b, Point c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

bool clockwise(Point a, Point b, Point c) {
    long long place = area(a, b, c);
    if (place < 0) return true;
    if (place > 0) return false;
    int sc = (b.x - a.x) * (c.x - b.x) + (b.y - a.y) * (c.y - b.y);
    return sc > 0;
}
 
inline bool intersect_1 (int a, int b, int c, int d) {
	if (a > b)  swap (a, b);
	if (c > d)  swap (c, d);
	return max(a,c) <= min(b,d);
}
 
bool intersect (Point a, Point b, Point c, Point d) {
	return intersect_1 (a.x, b.x, c.x, d.x)
		&& intersect_1 (a.y, b.y, c.y, d.y)
		&& area(a,b,c) * area(a,b,d) <= 0
		&& area(c,d,a) * area(c,d,b) <= 0;
}

void checkCrossing(int p1, int p2, std::vector<int> &spiral, std::vector<Point> &p) {
  for (int i = 0; i < (int) spiral.size() - 1; i++) {
    if (spiral[i] == p1 || spiral[i] == p2 || spiral[i + 1] == p1 || spiral[i + 1] == p2) {
      continue;
    }
    if (intersect(p[p1], p[p2], p[spiral[i]], p[spiral[i + 1]])) {
      quitf(_wa, "Segment %d-%d intersects segment %d-%d", p1, p2, spiral[i], spiral[i + 1]);
    }
  }
}

int main(int argc, char * argv[]) {
    registerTestlibCmd(argc, argv);

    int n = inf.readInt();
    std::vector<Point> p(n + 1);
    for (int i = 1; i <= n; i++) {
      p[i].x = inf.readInt();
      p[i].y = inf.readInt();
    }

    int nOuf = ouf.readInt();
    if (nOuf < 0 || nOuf > n) {
      quitf(_pe, "Integer between 1 and %d was expected, but %d found", n, nOuf);
    }
    if (nOuf != n) {
      quitf(_wa, "%d was expected, but %d found", n, nOuf);
    }

    std::vector<bool> used (n + 1, false);
    std::vector<int> spiral;
    for (int i = 1; i <= n; i++) {

      int next = ouf.readInt();
      
      if (next < 1 || next > n) {
        quitf(_pe, "Integer between 1 and %d was expected, but %d found", n, next);
      }

      if (used[next]) {
        quitf(_wa, "The point number %d is already used", next);
      }
      used[next] = true;

      spiral.push_back(next);

      if (spiral.size() >= 3 && !clockwise(p[spiral[spiral.size() - 3]], p[spiral[spiral.size() - 2]], p[spiral[spiral.size() - 1]]) )  {
          quitf(_wa, "Left turn detected: %d - %d - %d", spiral[spiral.size() - 3], spiral[spiral.size() - 2], spiral[spiral.size() - 1]);
      }

      if (spiral.size() >= 2) {
        checkCrossing(spiral[spiral.size() - 2], spiral[spiral.size() - 1], spiral, p);
      }

    }

    quitf(_ok, "Accepted");

}
