#include "testlib.h"
#include <string>
#include <vector>
#include <algorithm>

std::string validate(const std::string &s) {
	if (s.size() == 0) {
		return "the string is empty";
	}
	if (s.size() > 1 && s[0] == '0') {
		return "leading zero";
	}
	for (char c : s) {
		if (c < '0' || '9' < c) {
			return std::string("non-digit char ") + c;
		}
	}
	bool wasDigit[10] = {};
	for (char c : s) {
		wasDigit[c - '0'] = true;
	}
	int count = 0;
	for (int i = 0; i < 10; i++) {
		if (wasDigit[i]) {
			count++;
		}
	}
	if (count > 2) {
		std::string ans = "more than 2 digits: ";
		for (int i = 0; i < 10; i++) {
			if (wasDigit[i]) {
				ans += (char)('0' + i);
			}
		}
		return ans;
	}
	return ""; // OK
}

int cmp(const std::string &left, const std::string &right) {
	if (left.size() != right.size()) {
		return (int)left.size() - (int)right.size();
	}
	return left.compare(right);
}

std::string subtract(std::string from, std::string what) {
	if (cmp(from, what) < 0) {
		quitf(_fail, "internal error: subtract from %s < what %s", from.c_str(), what.c_str());
	}
	std::reverse(from.begin(), from.end());
	std::reverse(what.begin(), what.end());
	int carry = 0;
	for (int i = 0; i < (int)what.size() || carry != 0; i++) {
		carry = carry + 10 + (from[i] - '0') - (what[i] - '0');
		from[i] = (char)('0' + carry % 10);
		carry = carry / 10 - 1;
	}
	while (from.size() > 1 && from.back() == '0') {
		from.pop_back();
	}
	std::reverse(from.begin(), from.end());
	return from;
}

int main(int argc, char * argv[])
{
    registerTestlibCmd(argc, argv);
    
    int n = inf.readInt();
    inf.readEoln();

    std::vector<std::string> input;
    for (int i = 0; i < n; i++) {
    	input.push_back(inf.readString());
    }
    inf.readEof();

    std::vector<std::string> jOutput;
    for (int i = 0; i < n; i++) {
    	jOutput.push_back(ans.readString());
    }
    ans.readEof();

    std::vector<std::string> uOutput;
    for (int i = 0; i < n; i++) {
    	uOutput.push_back(ouf.readString());
    }
    ouf.readEof();

    for (const std::string &s : jOutput) {
    	std::string message = validate(s);
    	if (message != "") {
    		quitf(_fail, "invalid judge output line %s: %s", s.c_str(), message.c_str());
    	}
    }

    for (const std::string &s : uOutput) {
    	std::string message = validate(s);
    	if (message != "") {
    		quitf(_pe, "invalid user output line %s: %s", s.c_str(), message.c_str());
    	}
    }

    for (int i = 0; i < n; i++) {
    	std::string is = input[i];
    	std::string js = jOutput[i];
    	std::string us = uOutput[i];
    	if (js != us) {
   			int signJ;
   			std::string diffJ;
   			if (cmp(js, is) > 0) {
   				signJ = 1;
   				diffJ = subtract(js, is);
   			} else if (cmp(js, is) < 0) {
   				signJ = -1;
   				diffJ = subtract(is, js);
   			} else {
   				signJ = 0;
   				diffJ = "0";
   			}

   			int signU;
   			std::string diffU;
   			if (cmp(us, is) > 0) {
   				signU = 1;
   				diffU = subtract(us, is);
   			} else if (cmp(us, is) < 0) {
   				signU = -1;
   				diffU = subtract(is, us);
   			} else {
   				signU = 0;
   				diffU = "0";
   			}

   			if (cmp(diffU, diffJ) > 0) {
   				quitf(_wa, "user string %s farther than judge string %s from input string %s", us.c_str(), js.c_str(), is.c_str());
   			} else if (cmp(diffU, diffJ) == 0 && signU > signJ) {
   				quitf(_wa, "user string %s has the same diff as judge string %s but greater than input string %s", us.c_str(), js.c_str(), is.c_str());
   			} else {
   				quitf(_fail, "user string %s is better than judge string %s for input string %s", us.c_str(), js.c_str(), is.c_str());
   			}
    	}
    }
    
    quit(_ok, "");
}
