#include <cstdio>
#include <string>
#include <cassert>
#include <algorithm>

bool is2(int n) {
	bool used[10] = {};
	int count = 0;
	while (n != 0) {
		int d = n % 10;
		if (!used[d]) {
			count++;
			if (count > 2) {
				return false;
			}
			used[d] = true;
		}
		n /= 10;
	}
	return true;
}

int f(int n) {
	int d = 0;
	while (true) {
		if (is2(n - d)) {
			return n - d;
		}
		if (is2(n + d)) {
			return n + d;
		}
		d++;
	}
}

bool is2(const std::string &n) {
	bool used[10] = {};
	int count = 0;
	for (char c : n) {
		assert('0' <= c && c <= '9');
		if (!used[c - '0']) {
			count++;
			if (count > 2) {
				return false;
			}
			used[c - '0'] = true;
		}
	}
	return true;
}

std::string diff(std::string a, const std::string &b) {
	assert(a.size() == b.size());
	int carry = 0;
	for (int i = a.size() - 1; i >= 0; i--) {
		carry = carry + 10 + a[i] - b[i];
		a[i] = '0' + carry % 10;
		carry = carry / 10 - 1;
	}
	assert(carry == 0);
	return a;
}

void update(const std::string &n, std::string &ans, const std::string &cand) {
	if (ans == "") {
		ans = cand;
		return;
	}
	if (ans >= n && cand >= n) {
		if (cand < ans) {
			ans = cand;
		}
		return;
	}
	if (ans <= n && cand <= n) {
		if (cand > ans) {
			ans = cand;
		}
		return;
	}
	std::string ansDiff;
	if (ans >= n) {
		ansDiff = diff(ans, n);
	} else {
		ansDiff = diff(n, ans);
	}
	if (cand >= n) {
		std::string candDiff = diff(cand, n);
		if (candDiff < ansDiff) {
			ans = cand;
		}
		return;
	} else {
		std::string candDiff = diff(n, cand);
		if (candDiff <= ansDiff) {
			ans = cand;
		}
		return;
	}
}

std::string fast(const std::string &n) {
	if (is2(n)) {
		return n;
	}
	int sp = 1;
	while (n[sp] == n[0]) {
		sp++;
	}
	std::string ans = "";
	// 14999 -> 15111
	if (n[sp] < '9') {
		std::string t = n;
		t[sp]++;
		if (t[0] == t[sp]) {
			// 21999 -> 22000
			for (int j = sp + 1; j < (int)t.size(); j++) {
				t[j] = '0';
			}
		} else {
			// 14999 -> 15111
			for (int j = sp + 1; j < (int)t.size(); j++) {
				t[j] = std::min(t[0], t[sp]);
			}
		}
		update(n, ans, t);
	}
	// 93000 -> 92999
	if (n[sp] > '0') {
		std::string t = n;
		t[sp]--;
		if (t[0] == t[sp]) {
			// 23000 -> 22999
			for (int j = sp + 1; j < (int)t.size(); j++) {
				t[j] = '9';
			}
		} else {
			// 84000 -> 83888
			for (int j = sp + 1; j < (int)t.size(); j++) {
				t[j] = std::max(t[0], t[sp]);
			}
		}
		update(n, ans, t);
	}
	// 131325 -> 131331 / 131313
	int tp = sp + 1;
	while (n[tp] == n[0] || n[tp] == n[sp]) {
		tp++;
	}
	if (n[tp] > std::max(n[0], n[sp])) {
		std::string t = n;
		for (int j = tp; j < (int)t.size(); j++) {
			t[j] = std::max(n[0], n[sp]);
		}
		update(n, ans, t);
	} else if (n[tp] < std::min(n[0], n[sp])) {
		std::string t = n;
		for (int j = tp; j < (int)t.size(); j++) {
			t[j] = std::min(n[0], n[sp]);
		}
		update(n, ans, t);
	} else {
		assert(std::min(n[0], n[sp]) < n[tp] && n[tp] < std::max(n[0], n[sp]));
		{
			std::string t = n;
			t[tp] = std::max(n[0], n[sp]);
			for (int j = tp + 1; j < (int)t.size(); j++) {
				t[j] = std::min(n[0], n[sp]);
			}
			update(n, ans, t);
		}
		{
			std::string t = n;
			t[tp] = std::min(n[0], n[sp]);
			for (int j = tp + 1; j < (int)t.size(); j++) {
				t[j] = std::max(n[0], n[sp]);
			}
			update(n, ans, t);
		}
	}
	if (n[tp - 1] == std::min(n[0], n[sp])) {
		std::string t = n;
		t[tp - 1] = std::max(n[0], n[sp]);
		for (int j = tp; j < (int)t.size(); j++) {
			t[j] = std::min(n[0], n[sp]);
		}
		update(n, ans, t);
	} else {
		assert(n[tp - 1] == std::max(n[0], n[sp]));
		std::string t = n;
		t[tp - 1] = std::min(n[0], n[sp]);
		for (int j = tp; j < (int)t.size(); j++) {
			t[j] = std::max(n[0], n[sp]);
		}
		update(n, ans, t);
	}
	return ans;
}

/*
void research() {
	for (int i = 1; i <= 100000; i++) {
		if (to_string(f(i)) != fast(to_string(i))) {
			printf("!=: i=%d f=%d fast=%s\n", i, f(i), fast(to_string(i)).c_str());
		}
	}
	printf("done\n");
	std::exit(0);
}
*/

int main() {
	// research();
	freopen("twofold.in", "rt", stdin);
	freopen("twofold.out", "wt", stdout);
	int n;
	scanf("%d", &n);
	static char buffer[1048576 + 1];
	for (int i = 0; i < n; i++) {
		scanf("%1048576s", buffer);
		printf("%s\n", fast(buffer).c_str());
	}
	return 0;
}
