#include <cstdio>
#include <vector>
#include <algorithm>

const int BASE = 1000000000;

void check(bool e) {
  if (!e) {
    throw 1;
  }
}

struct BigInteger {
      
  std::vector<int> d;

  BigInteger(int value) {
    if (value >= BASE) {
      d.resize(2);
      d[0] = value % BASE;
      d[1] = value / BASE;
    } else {
      d.resize(1);
      d[0] = value;
    }
  }

  BigInteger& operator += (const BigInteger &sec) {
    int rem = 0;
    if (d.size() < sec.d.size()) {
      d.resize(sec.d.size());
    }
    int i;
    for (i = 0; i < (int)sec.d.size(); i++) {
      rem += d[i] + sec.d[i];
      d[i] = rem % BASE;
      rem /= BASE;
    }
    for (; rem > 0 && i < (int)d.size(); i++) {
      rem += d[i];
      d[i] = rem % BASE;
      rem /= BASE;      
    }
    if (rem > 0) {
      d.push_back(rem);
    }
    return *this;
  }

  BigInteger operator + (const BigInteger &sec) const {
    BigInteger res = *this;
    res += sec;
    return res;
  }

  void print() {
    printf("%d", d.back());
    for (int i = d.size() - 2; i >= 0; i--) {
      printf("%09d", d[i]);
    }
  }

  BigInteger operator * (const BigInteger &sec) const {
    BigInteger res(0);
    res.d.resize(d.size() + sec.d.size());
    for (int i = 0; i < (int)d.size(); i++) {
      long long rem = 0;
      int j;
      for (j = 0; j < (int)sec.d.size(); j++) {
         rem += res.d[i + j] + d[i] * (long long) sec.d[j];
         res.d[i + j] = (int) (rem % BASE);
         rem /= BASE;
      }
      if (rem > 0) {
        res.d[i + j] += rem;
      }
    }
    if (res.d.size() > 1 && res.d.back() == 0) {
      res.d.pop_back();
    }
    return res;
  }            
               
};

int main() {

  freopen("typesetter.in", "rt", stdin);
  freopen("typesetter.out", "wt", stdout);

  std::vector<int> count(26);
  for(;;) {
    int ch = getchar();
    if (ch >= 'a' && ch <= 'z') {
      count[ch - 'a']++;
    } else {
      break;
    }
  }

  int length = 0;
  for (int i = 0; i < 26; i++) {
    length += count[i];
  }

  std::vector<std::vector<BigInteger> > c(length + 1, std::vector<BigInteger>(length + 1, BigInteger(0)));
  for (int i = 1; i <= length; i++) {
    c[i][0] = BigInteger(1);
    c[i][1] = BigInteger(i);
  }
  for (int i = 2; i <= length; i++) {
    for (int j = 2; j <= std::min(length, i); j++) {
      c[i][j] = c[i - 1][j] + c[i - 1][j - 1];
    }
  }
  
  std::vector<BigInteger> ans(length + 1, BigInteger(0));
  ans[0] = BigInteger(1);
  for (int i = 0; i < 26; i++) {
    if (count[i] == 0) {
      continue;
    }
    std::vector<BigInteger> ans2 = ans;
    for (int len = 0; len <= length; len++) { // длина слов, которые получены ранее
      if (ans[len].d.size() == 1 && ans[len].d[0] == 0) {
        continue;
      }
      for (int k = 1; k <= count[i]; k++) { // количество букв в i-й группе, которые мы используем
        if (len + k > length) {
          continue;
        }
        ans2[len + k] += ans[len] * c[len + k][len];
      }
    }
    ans.swap(ans2);
  }

  BigInteger sum(0);
  for (int i = 1; i <= length; i++) {
    sum += ans[i];
  }
  sum.print();
  return 0;
}